@@ -9,7 +9,7 @@ logger = logging.getLogger(__name__)
 
 def get_sql(sql):
     if sql[-4:] == ".sql":
-        with open(sql, "r") as f:
+        with open(sql, encoding="utf8", errors="ignore") as f:
             return f.read()
     return sql
 
@@ -21,7 +21,7 @@ class Abstract_DB(ABC):
         print("Connected to DB")
 
     @abstractmethod
-    def set_up_connection(self):
+    def set_up_connection(self, _retry=2):
         pass
 
     @abstractmethod
